<?php

namespace Test\Test\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Test\Test\Http\Requests\TestingTblRequest;
use Test\Test\Models\TestingTbl;

/**
 * Admin web controller class.
 */
class TestingTblWorkflowController extends BaseController
{

    /**
     * Workflow controller function for testing_tbl.
     *
     * @param Model   $testing_tbl
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(TestingTblRequest $request, TestingTbl $testing_tbl, $step)
    {

        try {

            $testing_tbl->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('test::testing_tbl.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/testing_tbl/testing_tbl/' . $testing_tbl->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/testing_tbl/testing_tbl/' . $testing_tbl->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for testing_tbl.
     *
     * @param Model   $testing_tbl
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
     */

    public function getWorkflow(TestingTbl $testing_tbl, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $testing_tbl->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('test::testing_tbl.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('test::admin.testing_tbl.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('test::admin.testing_tbl.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('test::admin.testing_tbl.message', $data)->render();

        }

    }
}
