<?php

namespace Test\Test\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Test\Test\Models\TestingTbl;

class TestingTblPolicy
{

    /**
     * Determine if the given user can view the testing_tbl.
     *
     * @param UserPolicyInterface $authUser
     * @param TestingTbl $testing_tbl
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, TestingTbl $testing_tbl)
    {
        if ($authUser->canDo('test.testing_tbl.view') && $authUser->isAdmin()) {
            return true;
        }

        return $testing_tbl->user_id == user_id() && $testing_tbl->user_type == user_type();
    }

    /**
     * Determine if the given user can create a testing_tbl.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('test.testing_tbl.create');
    }

    /**
     * Determine if the given user can update the given testing_tbl.
     *
     * @param UserPolicyInterface $authUser
     * @param TestingTbl $testing_tbl
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, TestingTbl $testing_tbl)
    {
        if ($authUser->canDo('test.testing_tbl.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $testing_tbl->user_id == user_id() && $testing_tbl->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given testing_tbl.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, TestingTbl $testing_tbl)
    {
        return $testing_tbl->user_id == user_id() && $testing_tbl->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given testing_tbl.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, TestingTbl $testing_tbl)
    {
        if ($authUser->canDo('test.testing_tbl.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given testing_tbl.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, TestingTbl $testing_tbl)
    {
        if ($authUser->canDo('test.testing_tbl.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
