<?php

namespace Test\Test\Workflow;

use Test\Test\Models\TestingTbl;
use Validator;

class TestingTblValidator
{

    /**
     * Determine if the given testing_tbl is valid for complete status.
     *
     * @param TestingTbl $testing_tbl
     *
     * @return bool / Validator
     */
    public function complete(TestingTbl $testing_tbl)
    {
        return Validator::make($testing_tbl->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given testing_tbl is valid for verify status.
     *
     * @param TestingTbl $testing_tbl
     *
     * @return bool / Validator
     */
    public function verify(TestingTbl $testing_tbl)
    {
        return Validator::make($testing_tbl->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given testing_tbl is valid for approve status.
     *
     * @param TestingTbl $testing_tbl
     *
     * @return bool / Validator
     */
    public function approve(TestingTbl $testing_tbl)
    {
        return Validator::make($testing_tbl->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given testing_tbl is valid for publish status.
     *
     * @param TestingTbl $testing_tbl
     *
     * @return bool / Validator
     */
    public function publish(TestingTbl $testing_tbl)
    {
        return Validator::make($testing_tbl->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given testing_tbl is valid for archive status.
     *
     * @param TestingTbl $testing_tbl
     *
     * @return bool / Validator
     */
    public function archive(TestingTbl $testing_tbl)
    {
        return Validator::make($testing_tbl->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given testing_tbl is valid for unpublish status.
     *
     * @param TestingTbl $testing_tbl
     *
     * @return bool / Validator
     */
    public function unpublish(TestingTbl $testing_tbl)
    {
        return Validator::make($testing_tbl->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
